"""ARgorithmToolkit has multiple modules dealing with particular data
structures and algorithms.

Out of these modules, the utils modules is of upmost importance as the
classes within the modules are neccessary for any Argorithm:

    >>> import ARgorithmToolkit
"""
from ARgorithmToolkit.utils import *
from ARgorithmToolkit.vector import Vector
from ARgorithmToolkit.stack import Stack
from ARgorithmToolkit.queue import Queue
from ARgorithmToolkit.priorityqueue import PriorityQueue
from ARgorithmToolkit.array import Array
from ARgorithmToolkit.string import String
from ARgorithmToolkit.linkedlist import LinkedList,LinkedListNode,ForwardList
from ARgorithmToolkit.doublylinkedlist import DoublyLinkedList,DoublyLinkedListNode,List
from ARgorithmToolkit.map import Map
from ARgorithmToolkit.set import Set
